Set

Struct Set 

pub struct Set<T: Eq + Hash + Clone> { /* private fields */ }
OR-Set CRDT. See the module docs for semantics.

Implementations

Source

impl<T: Eq + Hash + Clone> Set<T>

pub fn new(replica: ReplicaId) -> Self

Create an empty set.

pub fn new_random() -> Self

Create a new instance with a random ReplicaId from OS entropy. See crate::new_replica_id.

pub fn replica_id(&self) -> ReplicaId

This replica’s id.

pub fn len(&self) -> usize

Number of distinct values currently in the set.

pub fn is_empty(&self) -> bool

Is the set empty?

pub fn contains(&self, value: &T) -> bool

Does the set contain value?

pub fn iter(&self) -> impl Iterator<Item = &T> + '_

Iterate over values currently in the set.

pub fn add(&mut self, value: T) -> SetOp<T>

Add value. If it’s already present, an additional tag is created; removing it then requires a remove op that observes both tags (which always happens when removes carry the tag list at remove-time).

pub fn remove(&mut self, value: &T) -> Option<SetOp<T>>

Remove value. No-op (returns None) if the value is not present.

pub fn apply(&mut self, op: SetOp<T>) -> Result<(), Error>

Apply a remote op. Idempotent.

pub fn merge(&mut self, other: &Self)

Merge all of other’s state into self.

pub fn ops(&self) -> &[SetOp<T>]

All ops in this set’s log.

pub fn ops_since<'a>( &'a self, since: &'a VersionVector, ) -> impl Iterator<Item = &'a SetOp<T>> + 'a

Iterate over ops not yet seen by since.

pub fn version(&self) -> &VersionVector

This replica’s current version vector.