pub struct MarkSet { /* private fields */ }Expand description
Set of marks active at a single character position.
Implementations
Sourceimpl MarkSet
impl MarkSet
Sourcepub fn value_of(&self, name: &str) -> Option<&str>
pub fn value_of(&self, name: &str) -> Option<&str>
String value for a valued mark, or None if absent or boolean.
Sourcepub fn iter(&self) -> impl Iterator<Item = &str> + '_
pub fn iter(&self) -> impl Iterator<Item = &str> + '_
Iterate over active mark names in lexicographic order.
Sourcepub fn iter_with_values(&self) -> impl Iterator<Item = (&str, &MarkValue)> + '_
pub fn iter_with_values(&self) -> impl Iterator<Item = (&str, &MarkValue)> + '_
Iterate over (name, MarkValue) pairs.
Sourcepub fn iter_booleans(&self) -> impl Iterator<Item = &str> + '_
pub fn iter_booleans(&self) -> impl Iterator<Item = &str> + '_
Iterate over only boolean-style marks.
Sourcepub fn iter_values(&self) -> impl Iterator<Item = (&str, &str)> + '_
pub fn iter_values(&self) -> impl Iterator<Item = (&str, &str)> + '_
Iterate over only valued marks as (name, value) pairs.